@@ -1036,7 +1036,8 @@ class Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Base
       host: options.fetch(:host) { rhost },
       client: options.fetch(:username) { self.username },
       server: options.fetch(:sname, nil),
-      realm: options.fetch(:realm) { self.realm }
+      realm: options.fetch(:realm) { self.realm },
+      offered_etypes: options.fetch(:offered_etypes) { self.offered_etypes }
     )
   end
 
