@@ -43,7 +43,7 @@ class MetasploitModule < Msf::Auxiliary
         'References' => [
           [ 'CVE', '2015-0964' ], # XSS vulnerability
           [ 'CVE', '2015-0965' ], # CSRF vulnerability
-          [ 'CVE', '2015-0966' ], # "techician/yZgO8Bvj" web interface backdoor
+          [ 'CVE', '2015-0966' ], # "technician/yZgO8Bvj" web interface backdoor
           [ 'URL', 'https://www.rapid7.com/blog/post/2015/06/05/r7-2015-01-csrf-backdoor-and-persistent-xss-on-arris-motorola-cable-modems/' ],
         ]
       )
