@@ -316,7 +316,7 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def start_http_server
-    start_service(
+    cmdstager_start_service(
       {
         'Uri' => {
           'Proc' => proc do |cli, req|
