@@ -6,6 +6,9 @@
 class MetasploitModule < Msf::Post
   include Msf::Post::File
   include Msf::Post::Windows::Priv
+  include Msf::Exploit::Deprecated
+
+  deprecated nil, 'The post/windows/gather/enum_browsers module now supersedes this module'
 
   def initialize(info = {})
     super(
