@@ -121,7 +121,7 @@ RSpec.describe 'LDAP modules' do
 
   allure_test_environment = AllureRspec.configuration.environment_properties
 
-  let_it_be(:current_platform) { Acceptance::Meterpreter.current_platform }
+  let_it_be(:current_platform) { Acceptance::Session.current_platform }
 
   # Driver instance, keeps track of all open processes/payloads/etc, so they can be closed cleanly
   let_it_be(:driver) do
@@ -196,7 +196,7 @@ RSpec.describe 'LDAP modules' do
         end
 
         validated_lines.each do |test_line|
-          test_line = Acceptance::Meterpreter.uncolorize(test_line)
+          test_line = Acceptance::Session.uncolorize(test_line)
           expect(test_line).to_not include('FAILED', '[-] FAILED', '[-] Exception', '[-] '), "Unexpected error: #{test_line}"
         end
 
@@ -286,12 +286,12 @@ RSpec.describe 'LDAP modules' do
   tests.each do |runtime_name, test_config|
     runtime_name = "#{runtime_name}#{ENV.fetch('RUNTIME_VERSION', '')}"
 
-    describe "#{Acceptance::Meterpreter.current_platform}/#{runtime_name}", focus: test_config[:focus] do
+    describe "#{Acceptance::Session.current_platform}/#{runtime_name}", focus: test_config[:focus] do
       test_config[:module_tests].each do |module_test|
         describe(
           module_test[:name],
           if:
-            Acceptance::Meterpreter.supported_platform?(module_test)
+            Acceptance::Session.supported_platform?(module_test)
         ) do
           let(:target) { Acceptance::Target.new(test_config[:target]) }
 
@@ -352,7 +352,7 @@ RSpec.describe 'LDAP modules' do
 
           context 'when targeting a session', if: module_test[:targets].include?(:session) do
             it(
-              "#{Acceptance::Meterpreter.current_platform}/#{runtime_name} session opens and passes the #{module_test[:name].inspect} tests"
+              "#{Acceptance::Session.current_platform}/#{runtime_name} session opens and passes the #{module_test[:name].inspect} tests"
             ) do
               with_test_harness(module_test) do |replication_commands|
                 # Ensure we have a valid session id; We intentionally omit this from a `before(:each)` to ensure the allure attachments are generated if the session dies
@@ -379,7 +379,7 @@ RSpec.describe 'LDAP modules' do
 
           context 'when targeting an rhost', if: module_test[:targets].include?(:rhost) do
             it(
-              "#{Acceptance::Meterpreter.current_platform}/#{runtime_name} rhost opens and passes the #{module_test[:name].inspect} tests"
+              "#{Acceptance::Session.current_platform}/#{runtime_name} rhost opens and passes the #{module_test[:name].inspect} tests"
             ) do
               with_test_harness(module_test) do |replication_commands|
                 use_module = "use #{module_test[:name]}"
