@@ -72,6 +72,8 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
             Msf::OptFloat.new('FloatValue', [false, 'A FloatValue which should be normalized before framework runs this module', 3.5])
           ]
         )
+
+        deregister_options('RHOSTS')
       end
 
       def run
@@ -113,6 +115,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
     allow(subject).to receive(:mod).and_return(current_mod)
 
     framework.modules.add_module_path(File.join(FILE_FIXTURES_PATH, 'modules'))
+    framework.modules.refresh_cache_from_module_files
   end
 
   describe '#cmd_check' do
@@ -124,7 +127,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         current_mod.datastore['RHOSTS'] = ''
         subject.cmd_check
         expected_output = [
-          'Msf::OptionValidateError The following options failed to validate: RHOSTS'
+          'Msf::OptionValidateError One or more options failed to validate: RHOSTS.'
         ]
 
         expect(@combined_output).to match_array(expected_output)
@@ -220,7 +223,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
       it 'notifies the user that this module does not support check' do
         subject.cmd_check
         expected_output = [
-          'Check failed: NoMethodError This module does not support check.'
+          'This module does not support check.'
         ]
 
         expect(@combined_output).to match_array(expected_output)
@@ -241,7 +244,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         current_mod.datastore['RHOSTS'] = nil
         subject.cmd_run
         expected_output = [
-          'Msf::OptionValidateError The following options failed to validate: RHOSTS'
+          'Msf::OptionValidateError One or more options failed to validate: RHOSTS.'
         ]
 
         expect(@combined_output).to match_array(expected_output)
@@ -253,7 +256,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         current_mod.datastore['RHOSTS'] = ''
         subject.cmd_run
         expected_output = [
-          'Msf::OptionValidateError The following options failed to validate: RHOSTS'
+          'Msf::OptionValidateError One or more options failed to validate: RHOSTS.'
         ]
 
         expect(@combined_output).to match_array(expected_output)
@@ -282,7 +285,7 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         subject.cmd_run
         expected_output = [
           'Exploit completed, but no session was created.',
-          'Msf::OptionValidateError The following options failed to validate: REQUIRED_PAYLOAD_OPTION'
+          'Msf::OptionValidateError One or more options failed to validate: REQUIRED_PAYLOAD_OPTION.'
         ]
 
         expect(@combined_output).to match_array(expected_output)
@@ -445,6 +448,20 @@ RSpec.describe Msf::Ui::Console::CommandDispatcher::Exploit do
         expect(@combined_output).to match_array(expected_output)
       end
 
+      it 'runs the module once, even if multiple rhost values are set' do
+        set_default_payload(current_mod)
+        current_mod.datastore.store('FloatValue', '10.0')
+        current_mod.datastore['RHOSTS'] = '192.0.2.1 192.0.2.2 192.0.2.3'
+        subject.cmd_run
+        expected_output = [
+          'Running with normalized datastore value 10.0',
+          'Cleanup',
+          'Exploit completed, but no session was created.'
+        ]
+
+        expect(@combined_output).to match_array(expected_output)
+      end
+
       it 'normalized the datastore before running' do
         set_default_payload(current_mod)
         current_mod.datastore.store('FloatValue', '5.0')
